Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src Add DP83865 to the supported PHY list (from OpenBSD).



details:   https://anonhg.NetBSD.org/src/rev/0102e9f155c9
branches:  trunk
changeset: 750575:0102e9f155c9
user:      jdc <jdc%NetBSD.org@localhost>
date:      Thu Jan 07 09:30:28 2010 +0000

description:
Add DP83865 to the supported PHY list (from OpenBSD).

diffstat:

 share/man/man4/gphyter.4 |  11 ++++++-----
 sys/dev/mii/gphyter.c    |  18 ++++++++++++------
 2 files changed, 18 insertions(+), 11 deletions(-)

diffs (73 lines):

diff -r 27bccbc0d61d -r 0102e9f155c9 share/man/man4/gphyter.4
--- a/share/man/man4/gphyter.4  Thu Jan 07 09:28:38 2010 +0000
+++ b/share/man/man4/gphyter.4  Thu Jan 07 09:30:28 2010 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: gphyter.4,v 1.2 2008/04/30 13:10:54 martin Exp $
+.\"    $NetBSD: gphyter.4,v 1.3 2010/01/07 09:30:29 jdc Exp $
 .\"
 .\" Copyright (c) 1998, 2001 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -33,15 +33,16 @@
 .Os
 .Sh NAME
 .Nm gphyter
-.Nd Driver for National Semiconductor DP83861 10/100/1000 Ethernet PHYs
+.Nd Driver for National Semiconductor DP83861, DP83865 and DP83891 10/100/1000
+Ethernet PHYs
 .Sh SYNOPSIS
 .Cd "gphyter* at mii? phy ?"
 .Sh DESCRIPTION
 The
 .Nm
-driver supports the National Semiconductor DP83861 and DP83891 (Gig PHYTER)
-10/100/1000 Ethernet PHYs.  These PHYs are found on a variety of CAT5 Gigabit
-Ethernet interfaces.
+driver supports the National Semiconductor DP83861, DP83865 and DP83891
+(Gig PHYTER) 10/100/1000 Ethernet PHYs.  These PHYs are found on a variety of
+CAT5 Gigabit Ethernet interfaces.
 .Sh SEE ALSO
 .Xr ifmedia 4 ,
 .Xr intro 4 ,
diff -r 27bccbc0d61d -r 0102e9f155c9 sys/dev/mii/gphyter.c
--- a/sys/dev/mii/gphyter.c     Thu Jan 07 09:28:38 2010 +0000
+++ b/sys/dev/mii/gphyter.c     Thu Jan 07 09:30:28 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: gphyter.c,v 1.27 2009/10/19 18:41:13 bouyer Exp $      */
+/*     $NetBSD: gphyter.c,v 1.28 2010/01/07 09:30:28 jdc Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -55,15 +55,18 @@
  */
 
 /*
  * driver for National Semiconductor's DP83891 and DP83861 `Gig PHYTER'
  * ethernet 10/100/1000 PHYs.  The DP83891 is an older, non-firmware-
  * driven version of the DP83861.
  *
- * Data Sheet available from www.national.com
+ * Data Sheets available from www.national.com:
+ *   http://www.national.com/ds/DP/DP83861.pdf
+ *   http://www.national.com/ds/DP/DP83865.pdf
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gphyter.c,v 1.27 2009/10/19 18:41:13 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gphyter.c,v 1.28 2010/01/07 09:30:28 jdc Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -99,6 +102,9 @@
        { MII_OUI_xxNATSEMI,            MII_MODEL_xxNATSEMI_DP83861,
          MII_STR_xxNATSEMI_DP83861 },
 
+       { MII_OUI_xxNATSEMI,            MII_MODEL_xxNATSEMI_DP83865,
+         MII_STR_xxNATSEMI_DP83865 },
+
        { MII_OUI_xxNATSEMI,            MII_MODEL_xxNATSEMI_DP83891,
          MII_STR_xxNATSEMI_DP83891 },
 
@@ -55,15 +55,18 @@
 
 /*
- * driver for National Semiconductor's DP83891 and DP83861 `Gig PHYTER'
- * ethernet 10/100/1000 PHYs.  The DP83891 is an older, non-firmware-
- * driven version of the DP83861.
+ * driver for National Semiconductor's DP83891, DP83861 and DP83865
+ * `Gig PHYTER' ethernet 10/100/1000 PHYs.  The DP83891 is an older,
+ * non-firmware-driven version of the DP83861.  The DP83865 is a low
+ * power version of the DP83861.
  *



Home | Main Index | Thread Index | Old Index